@@ -14,14 +14,15 @@ def main():
     parser.add_argument('--command', metavar='command', required=True, type=str, help='the command. Supported commands are: listen (run the webthing service), register (register and starts the webthing service as a systemd unit, deregister (deregisters the systemd unit), log (prints the log)')
     parser.add_argument('--port', metavar='port', required=True, type=int, help='the port of the webthing serivce')
     parser.add_argument('--gpio', metavar='gpio', required=False, type=int, help='the gpio number wired to the device')
+    parser.add_argument('--name', metavar='name', required=False, type=str, default="", help='the name')
     args = parser.parse_args()
 
     if args.command == 'listen':
-        print("running " + PACKAGENAME + " on port " + str(args.port) + "/gpio " + str(args.gpio))
-        run_server(int(args.port), int(args.gpio), DESCRIPTION)
+        print("running " + PACKAGENAME + "/" + args.name + " on port " + str(args.port) + "/gpio " + str(args.gpio))
+        run_server(int(args.port), int(args.gpio), args.name, DESCRIPTION)
     elif args.command == 'register':
-        print("register " + PACKAGENAME + " on port " + str(args.port) + "/gpio " + str(args.gpio) + " and starting it")
-        register(PACKAGENAME, ENTRY_POINT, int(args.port), int(args.gpio))
+        print("register " + PACKAGENAME + "/" + args.name + " on port " + str(args.port) + "/gpio " + str(args.gpio) + " and starting it")
+        register(PACKAGENAME, ENTRY_POINT, int(args.port), args.name, int(args.gpio))
     elif args.command == 'deregister':
         deregister(PACKAGENAME, int(args.port))
     elif args.command == 'log':
@@ -31,8 +32,7 @@ def main():
 
 
 if __name__ == '__main__':
-    log_level = os.environ.get("LOGLEVEL", "INFO")
-    logging.basicConfig(format='%(asctime)s %(levelname)-8s %(message)s', level=logging.getLevelName(log_level), datefmt='%Y-%m-%d %H:%M:%S')
+    logging.basicConfig(format='%(asctime)s %(levelname)-8s %(message)s', level=logging.INFO, datefmt='%Y-%m-%d %H:%M:%S')
 
     main()
 
